Index: components/user_prefs/tracked/pref_hash_store_impl.h |
diff --git a/components/user_prefs/tracked/pref_hash_store_impl.h b/components/user_prefs/tracked/pref_hash_store_impl.h |
index 1b5682eed4e83df46a039b50352e77da565756ff..76b6f7597e140ccbeb5a710bde0b239a3edbffe0 100644 |
--- a/components/user_prefs/tracked/pref_hash_store_impl.h |
+++ b/components/user_prefs/tracked/pref_hash_store_impl.h |
@@ -25,12 +25,12 @@ class PrefHashStoreImpl : public PrefHashStore { |
}; |
// Constructs a PrefHashStoreImpl that calculates hashes using |
// |seed| and |device_id| and stores them in |contents|. |
// |
// The same |seed| and |device_id| must be used to load and validate |
// previously stored hashes in |contents|. |
PrefHashStoreImpl(const std::string& seed, |
- const std::string& device_id, |
+ const std::string& legacy_device_id, |
bool use_super_mac); |
~PrefHashStoreImpl() override; |
@@ -25,12 +25,12 @@ class PrefHashStoreImpl : public PrefHashStore { |
}; |
// Constructs a PrefHashStoreImpl that calculates hashes using |
- // |seed| and |device_id| and stores them in |contents|. |
+ // |seed| and |legacy_device_id| and stores them in |contents|. |
// |
@@ -25,12 +25,12 @@ class PrefHashStoreImpl : public PrefHashStore { |
// |
- // The same |seed| and |device_id| must be used to load and validate |
+ // The same |seed| and |legacy_device_id| must be used to load and validate |
// previously stored hashes in |contents|. |
PrefHashStoreImpl(const std::string& seed, |